QuantizedMeshDecoder

Struct QuantizedMeshDecoder 

pub struct QuantizedMeshDecoder<'a> { /* private fields */ }
Quantized mesh decoder.

Decodes terrain mesh data from the quantized-mesh-1.0 format.

Implementations

Source

impl<'a> QuantizedMeshDecoder<'a>

pub fn new(data: &'a [u8]) -> Self

Create a new decoder from raw bytes.

Automatically detects and handles gzip compression.

pub fn decode(data: &[u8]) -> DecodeResult<DecodedMesh>

Decode the quantized-mesh data from a byte slice.

If the data is gzip compressed, it will be decompressed first.

pub fn decode_from<R: Read>(reader: R) -> DecodeResult<DecodedMesh>

Decode the quantized-mesh data from a reader.

If the data is gzip compressed, it will be decompressed first. The reader will be read to the end.