pub struct QuantizedMeshDecoder<'a> { /* private fields */ }Expand description
Quantized mesh decoder.
Decodes terrain mesh data from the quantized-mesh-1.0 format.
Implementations
Sourceimpl<'a> QuantizedMeshDecoder<'a>
impl<'a> QuantizedMeshDecoder<'a>
Sourcepub fn new(data: &'a [u8]) -> Self
pub fn new(data: &'a [u8]) -> Self
Create a new decoder from raw bytes.
Automatically detects and handles gzip compression.
Sourcepub fn decode(data: &[u8]) -> DecodeResult<DecodedMesh>
pub fn decode(data: &[u8]) -> DecodeResult<DecodedMesh>
Decode the quantized-mesh data from a byte slice.
If the data is gzip compressed, it will be decompressed first.
Sourcepub fn decode_from<R: Read>(reader: R) -> DecodeResult<DecodedMesh>
pub fn decode_from<R: Read>(reader: R) -> DecodeResult<DecodedMesh>
Decode the quantized-mesh data from a reader.
If the data is gzip compressed, it will be decompressed first. The reader will be read to the end.